@@ -27,16 +27,16 @@
 #include "gdisplay.h"
 #include "gimage_mask.h"
 #include "rect_select.h"
-#include "interface.h"
 #include "bezier_select.h"
 #include "bezier_selectP.h"
 #include "paths_dialogP.h"
 #include "selection_options.h"
 #include "undo.h"
 
-#include "libgimp/gimpintl.h"
 #include "libgimp/gimpmath.h"
 
+#include "libgimp/gimpintl.h"
+
 /* Bezier extensions made by Raphael FRANCOIS (fraph@ibm.net)
 
   BEZIER_EXTENDS VER 1.0 
@@ -409,6 +409,13 @@ bezier_select_reset (BezierSelect *bezier_sel)
   bezier_sel->scanlines = NULL;
 }
 
+void
+bezier_select_free (BezierSelect *bezier_sel)
+{
+  bezier_select_reset (bezier_sel);
+  g_free (bezier_sel);
+}
+
 /* Find the curve that points to this curve. This makes to_check point
  * the start of a curve. 
  */
@@ -608,6 +615,7 @@ bezier_edit_point_on_curve(int             x,
   BezierPoint  *next_curve;
   BezierPoint  *points = bezier_sel->points;
   BezierPoint  *start_pt = bezier_sel->points;
+  BezierPoint  *last_curve = NULL;
   gint point_counts = 0;
 
   /* find if the button press occurred on a point */
@@ -623,25 +631,46 @@ bezier_edit_point_on_curve(int             x,
 	  if (ModeEdit== EXTEND_REMOVE)
 	    {
 
-	      if(bevent->state & GDK_SHIFT_MASK)
+	      if((bevent->state & GDK_SHIFT_MASK) || (point_counts <= 7))
 		{
-		  delete_whole_curve(bezier_sel,start_pt);
-		}
-	      else if (point_counts <= 7)
-		{
-		  /* If we've got less then 7 points ie: 2 anchors points 4 controls 
-		     Then the curve is minimal closed curve.
-		     I've decided to not operate on this kind of curve because it    
-		     implies opening the curve and change some drawing states        
-		     Removing 1 point of curve that contains 2 point is something    
-		     similare to reconstruct the curve !!!
+		  /* Case 1: GDK_SHIFT_MASK - The user explicitly wishes the present 
+                     curve to go away.
+                     Case 2: The current implementation cannot cope with less than
+                     7 points ie: 2 anchors points and 4 controls: the minimal closed curve.
+                     Since the user wishes less than this implementation minimum,
+                     we take this for an implicit wish that the entire curve go away.
+                     G'bye dear curve. 
 		  */
-		  return(0); 
+
+		  delete_whole_curve(bezier_sel,start_pt);
+		  return (1);
 		}
 	      else if(!finded->prev || !finded->prev->prev) 
 		{
 		  /* This is the first point on the curve */
-		  /* FIXME g_print ("Del first point\n"); */
+		  /* Clear current anchor and control */
+		  bezier_sel->cur_anchor = NULL;
+		  bezier_sel->cur_control = NULL;
+		  /* Where are we?  reset to first point... */
+		  /*if(last_curve == NULL)*/
+		  if(start_pt == bezier_sel->points)
+		    {
+		      finded = bezier_sel->points;
+		      bezier_sel->points = finded->next->next->next;
+		      bezier_sel->points->prev = NULL;
+		    }
+		  else
+		    {
+ 		      finded = last_curve->next_curve; 
+ 		      last_curve->next_curve = finded->next->next->next; 
+ 		      last_curve->next_curve->prev = NULL; 
+		    }
+		  
+		  bezier_sel->num_points -= 3;
+		  
+		  g_free( finded->next->next );
+		  g_free( finded->next );
+		  g_free( finded );
 		}
 	      else if(!bezier_sel->closed && 
 		      (finded == bezier_sel->last_point ||
@@ -649,7 +678,21 @@ bezier_edit_point_on_curve(int             x,
 		       finded == bezier_sel->last_point->prev->prev))
 		{
 		  /* This is the last point on the curve */
-		  /* FIXME g_print ("Del last point\n"); */
+		  /* Clear current anchor and control */
+		  /* Where are we?  reset to last point... */
+		  finded =  bezier_sel->last_point->prev;
+		  bezier_sel->last_point = finded->prev->prev;
+		  bezier_sel->last_point->next = NULL;
+		  
+		  bezier_sel->cur_anchor = NULL;
+		  bezier_sel->cur_control = NULL;
+		 
+
+		  bezier_sel->num_points -= 3;
+		  
+		  g_free( finded->prev );
+		  g_free( finded->next );
+		  g_free( finded );
 		}
 	      else
 		{
@@ -742,6 +785,8 @@ bezier_edit_point_on_curve(int             x,
 	}
 
       next_curve = points->next_curve;
+      if(next_curve)
+	last_curve = points;
       points = points->next;
     } while (points != start_pt && points);
     start_pt = next_curve;
@@ -877,7 +922,8 @@ bezier_select_button_press (Tool           *tool,
 /* 	  } */
 
       bezier_sel->state = BEZIER_ADD;
-      bezier_sel->draw = BEZIER_DRAW_CURRENT | BEZIER_DRAW_HANDLES;
+      /*bezier_sel->draw = BEZIER_DRAW_CURVE; | BEZIER_DRAW_HANDLES;*/
+      bezier_sel->draw = BEZIER_DRAW_CURRENT;
 
       bezier_add_point (bezier_sel, BEZIER_ANCHOR, (gdouble)x, (gdouble)y);
       bezier_add_point (bezier_sel, BEZIER_CONTROL, (gdouble)x, (gdouble)y);
@@ -891,7 +937,10 @@ bezier_select_button_press (Tool           *tool,
       if(ModeEdit == EXTEND_EDIT)
 	{ 
 	  /* erase the handles */
-	  bezier_sel->draw = BEZIER_DRAW_ALL;  
+	  if(bezier_sel->closed)
+	    bezier_sel->draw = BEZIER_DRAW_ALL;  
+	  else
+	    bezier_sel->draw = BEZIER_DRAW_CURVE;  
 	  draw_core_pause (bezier_sel->core, tool);
 	  /* unset the current anchor and control */
 	  bezier_sel->cur_anchor = NULL;
@@ -927,10 +976,22 @@ bezier_select_button_press (Tool           *tool,
 	  bezier_sel->cur_anchor = NULL;
 	  bezier_sel->cur_control = NULL;
 
+	  /*kkk*/
+	  bezier_sel->draw = BEZIER_DRAW_ALL; 
+	  draw_core_resume (bezier_sel->core, tool);
+	  bezier_sel->draw = BEZIER_DRAW_ALL; 
+	  draw_core_pause (bezier_sel->core, tool);
+	  /*kkk*/
+
 	  grab_pointer = bezier_edit_point_on_curve(x,y,halfwidth,gdisp,bezier_sel,tool,bevent);
 
 	  bezier_sel->draw = BEZIER_DRAW_ALL; 
 	  draw_core_resume (bezier_sel->core, tool);
+	  if(bezier_sel->num_points == 0)
+	    {
+	      draw_core_pause(bezier_sel->core, tool);
+	      paths_dialog_set_default_op();
+	    }
 
 	  if(!grab_pointer)
 	    {
@@ -997,8 +1058,8 @@ bezier_select_button_press (Tool           *tool,
 	  bezier_add_point (bezier_sel, BEZIER_CONTROL, (gdouble)x, (gdouble)y);
 	  bezier_sel->last_point->next = curve_start;
 	  curve_start->prev = bezier_sel->last_point;
-	  bezier_sel->cur_anchor = curve_start;
-	  bezier_sel->cur_control = curve_start->next;
+ 	  bezier_sel->cur_anchor = curve_start;
+ 	  bezier_sel->cur_control = curve_start->next;
 
 	  bezier_sel->closed = 1;
 	  bezier_sel->state = BEZIER_EDIT;
@@ -1047,6 +1108,11 @@ bezier_select_button_press (Tool           *tool,
       else
 	{
 	  grab_pointer = bezier_edit_point_on_curve(x,y,halfwidth,gdisp,bezier_sel,tool,bevent);
+	  if(grab_pointer && bezier_sel->num_points == 0)
+	    {
+	      draw_core_pause(bezier_sel->core, tool);
+	      paths_dialog_set_default_op();
+	    }
 	}
 
       if (!grab_pointer && channel_value (bezier_sel->mask, x, y))
@@ -1074,7 +1140,8 @@ bezier_select_button_press (Tool           *tool,
 	      paths_dialog_set_default_op();
 	      bezier_start_new_segment(bezier_sel,x,y);
 	    }
-	  bezier_sel->draw = BEZIER_DRAW_ALL; 
+ 	  bezier_sel->draw = BEZIER_DRAW_ALL; 
+
 	  draw_core_resume (bezier_sel->core, tool);
 	}
       break;
@@ -1112,6 +1179,8 @@ bezier_select_button_release (Tool           *tool,
   paths_newpoint_current(bezier_sel,gdisp);
 }
 
+
+/* unused
 static void
 bez_copy_points(BezierSelect *tobez,
 		BezierSelect *frombez)
@@ -1143,7 +1212,6 @@ bez_copy_points(BezierSelect *tobez,
 
       if(pts->next_curve)
 	{
-/* 	  g_print ("bezier_paste_bezierselect_to_current:: Close last curve off \n"); */
 	  tobez->last_point->next = bpnt;
 	  bpnt->prev = tobez->last_point;
 	  bpnt = NULL;
@@ -1163,6 +1231,7 @@ bez_copy_points(BezierSelect *tobez,
       tobez->closed = 1;
     }
 }
+*/
 
 static void
 bezier_select_motion (Tool           *tool,
@@ -1436,12 +1505,12 @@ points_in_box(BezierPoint *points,
   return c;
 }
 
-static int
-bezier_point_on_curve(GDisplay     *gdisp,
-		      BezierSelect *bezier_sel,
-		      gint         x,
-		      gint         y,
-		      gint         halfwidth)
+static gint
+bezier_point_on_curve (GDisplay     *gdisp,
+		       BezierSelect *bezier_sel,
+		       gint          x,
+		       gint          y,
+		       gint          halfwidth)
 {
   BezierCheckPnts chkpnts;
   BezierPoint * points;
@@ -1455,41 +1524,45 @@ bezier_point_on_curve(GDisplay     *gdisp,
   chkpnts.halfwidth = halfwidth;
   chkpnts.found = FALSE;
 
-  if(cnt)
+  if (cnt)
     cnt->count = 0;
   points = bezier_sel->points;
   start_pt = bezier_sel->points;
 
-  if(bezier_sel->num_points >= 4)
+  if (bezier_sel->num_points >= 4)
     {
-      do {
-	point_counts = count_points_on_curve(points);
-	if(point_counts >= 4)
-	  {
-	    do {
-	      if(points_in_box(points,x,y))
+      do
+	{
+	  point_counts = count_points_on_curve(points);
+	  if (point_counts >= 4)
+	    {
+	      do
 		{
-		  bezier_draw_segment (bezier_sel, points,
-				       SUBDIVIDE, IMAGE_COORDS,
-				       bezier_check_points,
-				       &chkpnts);
+		  if (points_in_box (points, x, y))
+		    {
+		      bezier_draw_segment (bezier_sel, points,
+					   SUBDIVIDE, IMAGE_COORDS,
+					   bezier_check_points,
+					   &chkpnts);
+		    }
+		  points = next_anchor (points, &next_curve);
+		  /* 	  g_print ("next_anchor = %p\n",points); */
 		}
-	      points = next_anchor(points,&next_curve);
-	      /* 	  g_print ("next_anchor = %p\n",points); */
-	    } while (points != start_pt && points);
-	    if(cnt)
-	      cnt->count++;
-	    start_pt = next_curve;
-	    points = next_curve;
-	  }
-	else
-	  break; /* must be last curve since only this one is allowed < 4
-		  * points.
-		  */
-      } while(next_curve);
+	      while (points != start_pt && points);
+	      if (cnt)
+		cnt->count++;
+	      start_pt = next_curve;
+	      points = next_curve;
+	    }
+	  else
+	    break; /* must be last curve since only this one is allowed < 4
+		    * points.
+		    */
+	}
+      while (next_curve);
     }
 
-  return (chkpnts.found);
+  return chkpnts.found;
 }
 
 static void
@@ -1505,120 +1578,186 @@ bezier_select_cursor_update (Tool           *tool,
   gint halfwidth,dummy;
   gint x,y;
 
-  gdisp = (GDisplay *)gdisp_ptr;
+  gdisp = (GDisplay *) gdisp_ptr;
 
   bezier_sel = tool->private;
 
-  if(gdisp != tool->gdisp_ptr || bezier_sel->core->draw_state == INVISIBLE)
+  if (gdisp != tool->gdisp_ptr || bezier_sel->core->draw_state == INVISIBLE)
     {
-      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE1_CURSOR);
+      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+				    BEZIER_SELECT,
+				    CURSOR_MODIFIER_NONE,
+				    FALSE);
       return;
     }
 
   gdisplay_untransform_coords (gdisp, mevent->x, mevent->y, &x, &y, TRUE, 0);
 
   /* get halfwidth in image coord */
-  gdisplay_untransform_coords (gdisp, mevent->x + BEZIER_HALFWIDTH, 0, &halfwidth, &dummy, TRUE, 0);
+  gdisplay_untransform_coords (gdisp, mevent->x + BEZIER_HALFWIDTH, 0,
+			       &halfwidth, &dummy, TRUE, 0);
   halfwidth -= x;
 
-  on_control_pnt = bezier_on_control_point(gdisp,bezier_sel,x,y,halfwidth);
+  on_control_pnt = bezier_on_control_point (gdisp, bezier_sel, x, y, halfwidth);
 
-  on_curve = bezier_point_on_curve(gdisp,bezier_sel,x,y,halfwidth);
+  on_curve = bezier_point_on_curve (gdisp, bezier_sel, x, y, halfwidth);
 
-  if(bezier_sel->mask && bezier_sel->closed &&
-     channel_value(bezier_sel->mask, x, y) && 
-     !on_control_pnt &&
-     (!on_curve || ModeEdit != EXTEND_ADD))
+  if (bezier_sel->mask && bezier_sel->closed &&
+      channel_value(bezier_sel->mask, x, y) && 
+      !on_control_pnt &&
+      (!on_curve || ModeEdit != EXTEND_ADD))
     {
       in_selection_area = TRUE;
-      if ((mevent->state & GDK_SHIFT_MASK) && !(mevent->state & GDK_CONTROL_MASK))
-	gdisplay_install_tool_cursor (gdisp,GIMP_MOUSE1SELP_CURSOR );
-      else if ((mevent->state & GDK_CONTROL_MASK) && !(mevent->state & GDK_SHIFT_MASK))
-	gdisplay_install_tool_cursor (gdisp,GIMP_MOUSE1SELM_CURSOR );
-      else if ((mevent->state & GDK_CONTROL_MASK) && (mevent->state & GDK_SHIFT_MASK))
-	gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE1SELU_CURSOR);
-      else
-	gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE1SEL_CURSOR);
-      return;
-    }
-
-  if(mevent->state & GDK_MOD1_MASK)
-    {
-      /* Moving curve */
-      if(mevent->state & GDK_SHIFT_MASK)
+      if ((mevent->state & GDK_SHIFT_MASK) &&
+	  !(mevent->state & GDK_CONTROL_MASK))
 	{
-	  /* moving on 1 curve */
-	  gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE1MM_CURSOR);
+	  gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+					RECT_SELECT,
+					CURSOR_MODIFIER_PLUS,
+					FALSE);
+	}
+      else if ((mevent->state & GDK_CONTROL_MASK) &&
+	       !(mevent->state & GDK_SHIFT_MASK))
+	{
+	  gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+					RECT_SELECT,
+					CURSOR_MODIFIER_MINUS,
+					FALSE);
+	}
+      else if ((mevent->state & GDK_CONTROL_MASK) &&
+	       (mevent->state & GDK_SHIFT_MASK))
+	{
+	  gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+					RECT_SELECT,
+					CURSOR_MODIFIER_INTERSECT,
+					FALSE);
 	}
       else
 	{
-	  gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE1MM_CURSOR);
+	  gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+					RECT_SELECT,
+					CURSOR_MODIFIER_NONE,
+					FALSE);
+	}
+      return;
+    }
+
+  if (mevent->state & GDK_MOD1_MASK)
+    {
+      /* Moving curve */
+      if (mevent->state & GDK_SHIFT_MASK)
+	{
+	  /* moving on 1 curve */
+	  gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+					BEZIER_SELECT,
+					CURSOR_MODIFIER_MOVE,
+					FALSE);
+	}
+      else
+	{
+	  gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+					BEZIER_SELECT,
+					CURSOR_MODIFIER_MOVE,
+					FALSE);
 	}
     }
   else
     {
-      switch(ModeEdit)
+      switch (ModeEdit)
 	{
 	case EXTEND_NEW:
-	  if(on_control_pnt && bezier_sel->closed)
+	  if (on_control_pnt && bezier_sel->closed)
 	    {
-	      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE1CP_CURSOR);
+	      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+					    BEZIER_SELECT,
+					    CURSOR_MODIFIER_CONTROL,
+					    FALSE);
 /* 	      g_print ("add to curve cursor\n"); */
 	    }
-	  else if(on_curve)
+	  else if (on_curve)
 	    {
-	      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE1AP_CURSOR);
+	      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+					    BEZIER_SELECT,
+					    CURSOR_MODIFIER_NONE,
+					    FALSE);
 /* 	      g_print ("edit control point cursor\n"); */
 	    }
 	  else
 	    {
-	      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE1AP_CURSOR);
+	      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+					    BEZIER_SELECT,
+					    CURSOR_MODIFIER_NONE,
+					    FALSE);
 	    }
 	  break;
 	case EXTEND_ADD:
-	  if(on_curve)
+	  if (on_curve)
 	    {
-	      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE1P_CURSOR);
+	      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+					    BEZIER_SELECT,
+					    CURSOR_MODIFIER_PLUS,
+					    FALSE);
 /* 	      g_print ("add to curve cursor\n"); */
 	    }
 	  else
 	    {
-	      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE1_CURSOR);
+	      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+					    BEZIER_SELECT,
+					    CURSOR_MODIFIER_NONE,
+					    FALSE);
 /* 	      g_print ("default no action cursor\n"); */
 	    }
 	  break;
 	case EXTEND_EDIT:
-	  if(on_control_pnt)
+	  if (on_control_pnt)
 	    {
-	      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE1CP_CURSOR);
+	      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+					    BEZIER_SELECT,
+					    CURSOR_MODIFIER_CONTROL,
+					    FALSE);
 /* 	      g_print ("edit control point cursor\n"); */
 	    }
 	  else
 	    {
-	      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE1_CURSOR);
+	      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+					    BEZIER_SELECT,
+					    CURSOR_MODIFIER_NONE,
+					    FALSE);
 /* 	      g_print ("default no action cursor\n"); */
 	    }
 	  break;
 	case EXTEND_REMOVE:
-	  if(on_control_pnt && mevent->state & GDK_SHIFT_MASK)
+	  if (on_control_pnt && mevent->state & GDK_SHIFT_MASK)
 	    {
-	      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE1M_CURSOR);
-	      g_print ("delete whole curve cursor\n");
+	      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+					    BEZIER_SELECT,
+					    CURSOR_MODIFIER_MINUS,
+					    FALSE);
+/*            g_print ("delete whole curve cursor\n"); */
 	    }
-	  else if(on_control_pnt)
+	  else if (on_control_pnt)
 	    {
-	      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE1M_CURSOR);
+	      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+					    BEZIER_SELECT,
+					    CURSOR_MODIFIER_MINUS,
+					    FALSE);
 /* 	      g_print ("remove point cursor\n"); */
 	    }
 	  else
 	    {
-	      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE1_CURSOR);
+	      gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+					    BEZIER_SELECT,
+					    CURSOR_MODIFIER_NONE,
+					    FALSE);
 /* 	      g_print ("default no action cursor\n"); */
 	    }
 	  break;
 	default:
 	  g_print ("In default\n");
-	  gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE1_CURSOR);
+	  gdisplay_install_tool_cursor (gdisp, GIMP_MOUSE_CURSOR,
+					BEZIER_SELECT,
+					CURSOR_MODIFIER_NONE,
+					FALSE);
 	  break;
 	}
     }
@@ -1699,7 +1838,9 @@ bezier_draw(GDisplay * gdisp,BezierSelect * bezier_sel)
       bezier_draw_handles (bezier_sel,0);
     }
   else if (draw_handles) 
-    bezier_draw_handles (bezier_sel,0); 
+    {
+      bezier_draw_handles (bezier_sel,0); 
+    }
 
 }
 
@@ -1741,6 +1882,7 @@ bezier_add_point (BezierSelect *bezier_sel,
       newpt->type = BEZIER_ANCHOR;
       bezier_sel->last_point->next_curve = newpt;
       bezier_sel->last_point = newpt;
+      bezier_sel->cur_anchor = newpt;
     }
   else
     {
@@ -1816,8 +1958,6 @@ bezier_draw_handles (BezierSelect *bezier_sel,gint doAll)
   BezierPoint * points;
   int num_points;
 
-/*   g_print ("bezier_draw_handles cur_anchor = %p\n",bezier_sel->cur_anchor); */
-
   points = bezier_sel->points;
   num_points = bezier_sel->num_points;
 
@@ -2309,10 +2449,10 @@ bezier_convert_line (GSList ** scanlines,
 		     int       x2,
 		     int       y2)
 {
-  int dx, dy; 
-  int error, inc; 
-  int tmp;
-  int slope;
+  int    dx, dy; 
+  int    error, inc; 
+  int    tmp;
+  double slope;
 
   if (y1 == y2)
     return;
@@ -2335,7 +2475,7 @@ bezier_convert_line (GSList ** scanlines,
       else
 	{
 	  slope = (double) (y2 - y1) / (double) (x2 - x1); 
-	  x1 = x2 + (0 - y2) / slope;
+	  x1 = x2 + (int)(0.5 + (double)(0 - y2) / slope);
 	  y1 = 0;
 	}
     }
@@ -2352,7 +2492,7 @@ bezier_convert_line (GSList ** scanlines,
       else
 	{
 	  slope = (double) (y2 - y1) / (double) (x2 - x1); 
-	  x2 = x1 + (height - y1) / slope;
+	  x2 = x1 + (int)(0.5 + (double)(height - y1) / slope);
 	  y2 = height;
 	}
     }
