@@ -261,10 +261,10 @@ color_picker_button_press (Tool           *tool,
 
 	case INDEXED_GIMAGE: case INDEXEDA_GIMAGE:
 	  info_dialog_add_label (color_picker_info, _("Index:"), index_buf);
-	  info_dialog_add_label (color_picker_info, _("Alpha:"), alpha_buf);
 	  info_dialog_add_label (color_picker_info, _("Red:"), red_buf);
 	  info_dialog_add_label (color_picker_info, _("Green:"), green_buf);
 	  info_dialog_add_label (color_picker_info, _("Blue:"), blue_buf);
+	  info_dialog_add_label (color_picker_info, _("Alpha:"), alpha_buf);
 	  info_dialog_add_label (color_picker_info, _("Hex Triplet"), hex_buf);
 	  break;
 
@@ -423,9 +423,15 @@ color_picker_cursor_update (Tool           *tool,
 			       FALSE, FALSE);
 
   if (gimage_pick_correlate_layer (gdisp->gimage, x, y))
-    gdisplay_install_tool_cursor (gdisp, GIMP_COLOR_PICKER_CURSOR);
+    gdisplay_install_tool_cursor (gdisp, GIMP_COLOR_PICKER_CURSOR,
+				  COLOR_PICKER,
+				  CURSOR_MODIFIER_NONE,
+				  FALSE);
   else
-    gdisplay_install_tool_cursor (gdisp, GDK_TOP_LEFT_ARROW);
+    gdisplay_install_tool_cursor (gdisp, GIMP_BAD_CURSOR,
+				  COLOR_PICKER,
+				  CURSOR_MODIFIER_NONE,
+				  FALSE);
 }
 
 static void
@@ -477,6 +483,7 @@ pick_color_do (GimpImage    *gimage,
   GetColorFunc get_color_func;
   GtkObject *get_color_obj;
 
+
   if (!drawable && !sample_merged) 
     return FALSE;
 
@@ -519,16 +526,16 @@ pick_color_do (GimpImage    *gimage,
 	  if ((tmp_color = (*get_color_func) (get_color_obj, i, j)))
 	    {
 	      count++;
-
+	      
 	      color_avg[RED_PIX]   += tmp_color[RED_PIX];
 	      color_avg[GREEN_PIX] += tmp_color[GREEN_PIX];
 	      color_avg[BLUE_PIX]  += tmp_color[BLUE_PIX];
 	      if (has_alpha)
 		color_avg[ALPHA_PIX] += tmp_color[3];
-
+	      
 	      g_free (tmp_color);
 	    }
-
+      
       color[RED_PIX]   = (guchar) (color_avg[RED_PIX] / count);
       color[GREEN_PIX] = (guchar) (color_avg[GREEN_PIX] / count);
       color[BLUE_PIX]  = (guchar) (color_avg[BLUE_PIX] / count);
@@ -640,6 +647,7 @@ color_picker_info_update (Tool     *tool,
       switch (sample_type)
 	{
 	case RGB_GIMAGE: case RGBA_GIMAGE:
+	  g_snprintf (index_buf, MAX_INFO_BUF, _("N/A"));
 	  g_snprintf (red_buf,   MAX_INFO_BUF, "%d", col_value [RED_PIX]);
 	  g_snprintf (green_buf, MAX_INFO_BUF, "%d", col_value [GREEN_PIX]);
 	  g_snprintf (blue_buf,  MAX_INFO_BUF, "%d", col_value [BLUE_PIX]);
@@ -658,13 +666,13 @@ color_picker_info_update (Tool     *tool,
 
 	case INDEXED_GIMAGE: case INDEXEDA_GIMAGE:
 	  g_snprintf (index_buf, MAX_INFO_BUF, "%d", col_value [4]);
+	  g_snprintf (red_buf,   MAX_INFO_BUF, "%d", col_value [RED_PIX]);
+	  g_snprintf (green_buf, MAX_INFO_BUF, "%d", col_value [GREEN_PIX]);
+	  g_snprintf (blue_buf,  MAX_INFO_BUF, "%d", col_value [BLUE_PIX]);
 	  if (sample_type == INDEXEDA_GIMAGE)
 	    g_snprintf (alpha_buf, MAX_INFO_BUF, "%d", col_value [ALPHA_PIX]);
 	  else
 	    g_snprintf (alpha_buf, MAX_INFO_BUF, _("N/A"));
-	  g_snprintf (red_buf,   MAX_INFO_BUF, "%d", col_value [RED_PIX]);
-	  g_snprintf (green_buf, MAX_INFO_BUF, "%d", col_value [GREEN_PIX]);
-	  g_snprintf (blue_buf,  MAX_INFO_BUF, "%d", col_value [BLUE_PIX]);
 	  g_snprintf (hex_buf,   MAX_INFO_BUF, "#%.2x%.2x%.2x",
 		      col_value [RED_PIX],
 		      col_value [GREEN_PIX],
@@ -752,7 +760,6 @@ tools_free_color_picker (Tool *tool)
       info_dialog_free (color_picker_info);
       color_picker_info = NULL;
 
-      color_panel_free (color_panel);
       color_panel = NULL;
     }
 
