@@ -15,17 +15,19 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
+#include "config.h"
+
 #include "appenv.h"
 #include "about_dialog.h"
 #include "app_procs.h"
 #include "brush_select.h"
-#include "colormaps.h"
 #include "colormap_dialog.i.h"
 #include "color_area.h"
 #include "commands.h"
 #include "convert.h"
 #include "desaturate.h"
 #include "devices.h"
+#include "docindex.h"
 #include "channel_ops.h"
 #include "drawable.h"
 #include "equalize.h"
@@ -56,8 +58,6 @@
 #include "tools.h"
 #include "undo.h"
 
-#include "config.h"
-
 #include "libgimp/gimpmath.h"
 #include "libgimp/gimpintl.h"
 
@@ -65,27 +65,20 @@
         gdisp = gdisplay_active (); \
         if (!gdisp) return
 
-typedef struct
-{
-  Resize    *resize;
-  GimpImage *gimage;
-} ImageResize;
-
 /*  external functions  */
 extern void   layers_dialog_layer_merge_query (GImage *, gboolean);
 
 /*  local functions  */
-static void   image_resize_callback        (GtkWidget *, gpointer);
-static void   image_scale_callback         (GtkWidget *, gpointer);
-static void   image_cancel_callback        (GtkWidget *, gpointer);
-static void   gimage_mask_feather_callback (GtkWidget *, gdouble, GimpUnit,
-					    gpointer);
-static void   gimage_mask_border_callback  (GtkWidget *, gdouble, GimpUnit,
-					    gpointer);
-static void   gimage_mask_grow_callback    (GtkWidget *, gdouble, GimpUnit,
-					    gpointer);
-static void   gimage_mask_shrink_callback  (GtkWidget *, gdouble, GimpUnit,
-					    gpointer);
+static void     image_resize_callback        (GtkWidget *, gpointer);
+static void     image_scale_callback         (GtkWidget *, gpointer);
+static void     gimage_mask_feather_callback (GtkWidget *, gdouble, GimpUnit,
+					      gpointer);
+static void     gimage_mask_border_callback  (GtkWidget *, gdouble, GimpUnit,
+		  			      gpointer);
+static void     gimage_mask_grow_callback    (GtkWidget *, gdouble, GimpUnit,
+					      gpointer);
+static void     gimage_mask_shrink_callback  (GtkWidget *, gdouble, GimpUnit,
+					      gpointer);
 
 /*  local variables  */
 static gdouble   selection_feather_radius    = 5.0;
@@ -257,12 +250,15 @@ edit_clear_cmd_callback (GtkWidget *widget,
 
 void
 edit_fill_cmd_callback (GtkWidget *widget,
-			gpointer   client_data)
+			gpointer   callback_data,
+			guint      callback_action)
 {
+  GimpFillType fill_type;
   GDisplay *gdisp;
   return_if_no_display (gdisp);
 
-  edit_fill (gdisp->gimage, gimage_active_drawable (gdisp->gimage));
+  fill_type = (GimpFillType) callback_action;
+  edit_fill (gdisp->gimage, gimage_active_drawable (gdisp->gimage), fill_type);
   gdisplays_flush ();
 }
 
@@ -598,25 +594,6 @@ view_nav_window_cmd_callback (GtkWidget *widget,
     }
 }
 
-void
-view_undo_history_cmd_callback (GtkWidget *widget,
-				gpointer   client_data)
-{
-  GDisplay *gdisp;
-  GImage   *gimage;
-  return_if_no_display (gdisp);
-
-  gimage = gdisp->gimage;
-
-  if (!gimage->undo_history)
-    gimage->undo_history = undo_history_new (gimage);
-
-  if (!GTK_WIDGET_VISIBLE (gimage->undo_history))
-    gtk_widget_show (gimage->undo_history);
-  else
-    gdk_window_raise (gimage->undo_history->window);
-}
-
 void
 view_toggle_selection_cmd_callback (GtkWidget *widget,
 				    gpointer   client_data)
@@ -828,6 +805,7 @@ image_resize_cmd_callback (GtkWidget *widget,
   image_resize->resize = resize_widget_new (ResizeWidget,
 					    ResizeImage,
 					    GTK_OBJECT (gimage),
+					    "destroy",
 					    gimage->width,
 					    gimage->height,
 					    gimage->xresolution,
@@ -835,9 +813,14 @@ image_resize_cmd_callback (GtkWidget *widget,
 					    gimage->unit,
 					    gdisp->dot_for_dot,
 					    image_resize_callback,
-					    image_cancel_callback,
+					    NULL,
 					    image_resize);
 
+  gtk_signal_connect_object (GTK_OBJECT (image_resize->resize->resize_shell),
+			     "destroy",
+			     GTK_SIGNAL_FUNC (g_free),
+			     (GtkObject *) image_resize);
+
   gtk_widget_show (image_resize->resize->resize_shell);
 }
 
@@ -859,6 +842,7 @@ image_scale_cmd_callback (GtkWidget *widget,
   image_scale->resize = resize_widget_new (ScaleWidget,
 					   ResizeImage,
 					   GTK_OBJECT (gimage),
+					   "destroy",
 					   gimage->width,
 					   gimage->height,
 					   gimage->xresolution,
@@ -866,9 +850,14 @@ image_scale_cmd_callback (GtkWidget *widget,
 					   gimage->unit,
 					   gdisp->dot_for_dot,
 					   image_scale_callback,
-					   image_cancel_callback,
+					   NULL,
 					   image_scale);
 
+  gtk_signal_connect_object (GTK_OBJECT (image_scale->resize->resize_shell),
+			     "destroy",
+			     GTK_SIGNAL_FUNC (g_free),
+			     (GtkObject *) image_scale);
+
   gtk_widget_show (image_scale->resize->resize_shell);
 }
 
@@ -1210,6 +1199,13 @@ dialogs_device_status_cmd_callback (GtkWidget *widget,
   device_status_create ();
 }
 
+void
+dialogs_document_index_cmd_callback (GtkWidget *widget,
+				     gpointer   client_data) 
+{
+  document_index_create ();
+}
+
 void
 dialogs_error_console_cmd_callback (GtkWidget *widget,
 				    gpointer   client_data) 
@@ -1236,6 +1232,25 @@ dialogs_display_filters_cmd_callback (GtkWidget *widget,
     gdk_window_raise (gdisp->cd_ui->window);
 }
 
+void
+dialogs_undo_history_cmd_callback (GtkWidget *widget,
+				   gpointer   client_data)
+{
+  GDisplay *gdisp;
+  GImage   *gimage;
+  return_if_no_display (gdisp);
+
+  gimage = gdisp->gimage;
+
+  if (!gimage->undo_history)
+    gimage->undo_history = undo_history_new (gimage);
+
+  if (!GTK_WIDGET_VISIBLE (gimage->undo_history))
+    gtk_widget_show (gimage->undo_history);
+  else
+    gdk_window_raise (gimage->undo_history->window);
+}
+
 void
 dialogs_module_browser_cmd_callback (GtkWidget *widget,
 				     gpointer   client_data)
@@ -1252,7 +1267,7 @@ void
 help_help_cmd_callback (GtkWidget *widget,
 			gpointer   client_data)
 {
-  gimp_help (NULL);
+  gimp_standard_help_func (NULL);
 }
 
 void
@@ -1290,6 +1305,8 @@ image_resize_callback (GtkWidget *widget,
 
   image_resize = (ImageResize *) client_data;
 
+  gtk_widget_set_sensitive (image_resize->resize->resize_shell, FALSE);
+
   if ((gimage = image_resize->gimage) != NULL)
     {
       if (image_resize->resize->width > 0 &&
@@ -1310,102 +1327,25 @@ image_resize_callback (GtkWidget *widget,
 	}
     }
 
-  resize_widget_free (image_resize->resize);
-  g_free (image_resize);
+  gtk_widget_destroy (image_resize->resize->resize_shell);
 }
 
 static void
 image_scale_callback (GtkWidget *widget,
 		      gpointer   client_data)
 {
-  ImageResize *image_scale;
-  GImage      *gimage;
-  gboolean     rulers_flush = FALSE;
-  gboolean     display_flush = FALSE;  /* this is a bit ugly: 
-				          we hijack the flush variable 
-					  to check if an undo_group was 
-					  already started */
+  ImageResize *image_scale = NULL;
 
-  image_scale = (ImageResize *) client_data;
+  g_assert ((image_scale = (ImageResize *) client_data) != NULL);
+  g_assert (image_scale->gimage != NULL);
 
-  if ((gimage = image_scale->gimage) != NULL)
+  gtk_widget_set_sensitive (image_scale->resize->resize_shell, FALSE);
+
+  if (resize_check_layer_scaling (image_scale))
     {
-      if (image_scale->resize->resolution_x != gimage->xresolution ||
-	  image_scale->resize->resolution_y != gimage->yresolution)
-	{
-	  undo_push_group_start (gimage, IMAGE_SCALE_UNDO);
-	  
-	  gimage_set_resolution (gimage,
-				 image_scale->resize->resolution_x,
-				 image_scale->resize->resolution_y);
-
-	  rulers_flush = TRUE;
-	  display_flush = TRUE;
-	}
-
-      if (image_scale->resize->unit != gimage->unit)
-	{
-	  if (!display_flush)
-	    undo_push_group_start (gimage, IMAGE_SCALE_UNDO);
-
-	  gimage_set_unit (gimage, image_scale->resize->unit);
-	  gdisplays_setup_scale (gimage);
-	  gdisplays_resize_cursor_label (gimage);
-
-	  rulers_flush = TRUE;
-	  display_flush = TRUE;
-	}
-
-      if (image_scale->resize->width != gimage->width ||
-	  image_scale->resize->height != gimage->height)
-	{
-	  if (image_scale->resize->width > 0 &&
-	      image_scale->resize->height > 0) 
-	    {
-	      if (!display_flush)
-		undo_push_group_start (gimage, IMAGE_SCALE_UNDO);
-
-	      gimage_scale (gimage,
-			    image_scale->resize->width,
-			    image_scale->resize->height);
-
-	      display_flush = TRUE;
-	    }
-	  else
-	    {
-	      g_message (_("Scale Error: Both width and height must be "
-			   "greater than zero."));
-	      return;
-	    }
-	}
-
-      if (rulers_flush)
-	{
-	  gdisplays_setup_scale (gimage);
-	  gdisplays_resize_cursor_label (gimage);
-	}
-      
-      if (display_flush)
-	{
-	  undo_push_group_end (gimage);
-	  gdisplays_flush ();
-	}
+      resize_scale_implement (image_scale);
+      gtk_widget_destroy (image_scale->resize->resize_shell);
     }
-
-  resize_widget_free (image_scale->resize);
-  g_free (image_scale);
-}
-
-static void
-image_cancel_callback (GtkWidget *widget,
-		       gpointer   client_data)
-{
-  ImageResize *image_resize;
-
-  image_resize = (ImageResize *) client_data;
-
-  resize_widget_free (image_resize->resize);
-  g_free (image_resize);
 }
 
 static void
