@@ -23,6 +23,7 @@
 #include "paint_funcs.h"
 #include "paint_options.h"
 #include "selection_options.h"
+#include "gtkhwrapbox.h"
 
 #include "libgimp/gimpunitmenu.h"
 
@@ -51,23 +52,48 @@ static void                   paint_pressure_options_reset (PaintPressureOptions
 /*  ui helper functions  ******************************************************/
 
 static void
-tool_options_opacity_adjustment_update (GtkWidget *widget,
-					gpointer   data)
+tool_options_opacity_adjustment_update (GtkAdjustment *adjustment,
+					gpointer       data)
 {
+  gtk_signal_handler_block_by_data (GTK_OBJECT (data), adjustment);
   gimp_context_set_opacity (GIMP_CONTEXT (data),
-			    GTK_ADJUSTMENT (widget)->value / 100);
+			    adjustment->value / 100);
+  gtk_signal_handler_unblock_by_data (GTK_OBJECT (data), adjustment);
+}
+
+static void
+tool_options_opacity_changed (GimpContext *context,
+			      gdouble      opacity,
+			      gpointer     data)
+{
+  gtk_signal_handler_block_by_data (GTK_OBJECT (data), context);
+  gtk_adjustment_set_value (GTK_ADJUSTMENT (data), opacity * 100);
+  gtk_signal_handler_unblock_by_data (GTK_OBJECT (data), context);
 }
 
 static void
 tool_options_paint_mode_update (GtkWidget *widget,
 				gpointer   data)
 {
-  GimpContext *context;
+  LayerModeEffects  paint_mode;
+  PaintOptions     *options;
 
-  context = (GimpContext *) gtk_object_get_user_data (GTK_OBJECT (widget));
+  paint_mode = (LayerModeEffects) gtk_object_get_user_data (GTK_OBJECT (widget));
+  options    = (PaintOptions *) data;
 
-  gimp_context_set_paint_mode (GIMP_CONTEXT (context),
-			       (LayerModeEffects) data);
+  gtk_signal_handler_block_by_data (GTK_OBJECT (options->context),
+				    options->paint_mode_w);
+  gimp_context_set_paint_mode (GIMP_CONTEXT (options->context), paint_mode);
+  gtk_signal_handler_unblock_by_data (GTK_OBJECT (options->context),
+				      options->paint_mode_w);
+}
+
+static void
+tool_options_paint_mode_changed (GimpContext      *context,
+				 LayerModeEffects  paint_mode,
+				 gpointer          data)
+{
+  gimp_option_menu_set_history (GTK_OPTION_MENU (data), (gpointer) paint_mode);
 }
 
 /*  tool options functions  ***************************************************/
@@ -140,6 +166,7 @@ selection_options_init (SelectionOptions     *options,
   options->feather_radius = options->feather_radius_d = 10.0;
   options->antialias      = options->antialias_d      = TRUE;
   options->sample_merged  = options->sample_merged_d  = FALSE;
+  options->threshold                                  = default_threshold;
   options->fixed_size     = options->fixed_size_d     = FALSE;
   options->fixed_height   = options->fixed_height_d   = 1;
   options->fixed_width    = options->fixed_width_d    = 1;
@@ -149,6 +176,7 @@ selection_options_init (SelectionOptions     *options,
   options->feather_radius_w = NULL;
   options->antialias_w      = NULL;
   options->sample_merged_w  = NULL;
+  options->threshold_w      = NULL;
   options->fixed_size_w     = NULL;
   options->fixed_height_w   = NULL;
   options->fixed_width_w    = NULL;
@@ -232,17 +260,12 @@ selection_options_init (SelectionOptions     *options,
       break;
     }
 
-  /*  the sample merged option  */
-  switch (tool_type)
+  /*  selection tools which operate on contiguous regions  */
+  if (tool_type == FUZZY_SELECT)
     {
-    case RECT_SELECT:
-    case ELLIPSE_SELECT:
-    case FREE_SELECT:
-    case BEZIER_SELECT:
-    case ISCISSORS:
-      break;
-    case FUZZY_SELECT:
-    case BY_COLOR_SELECT:
+      GtkWidget *hbox;
+
+      /*  the sample merged toggle  */
       options->sample_merged_w =
 	gtk_check_button_new_with_label (_("Sample Merged"));
       gtk_box_pack_start (GTK_BOX (vbox), options->sample_merged_w,
@@ -253,9 +276,27 @@ selection_options_init (SelectionOptions     *options,
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (options->sample_merged_w),
 				    options->sample_merged_d);
       gtk_widget_show (options->sample_merged_w);
-      break;
-    default:
-      break;
+
+      /*  the threshold scale  */
+      hbox = gtk_hbox_new (FALSE, 1);
+      gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+      gtk_widget_show (hbox);
+  
+      label = gtk_label_new (_("Threshold:"));
+      gtk_misc_set_alignment (GTK_MISC (label), 1.0, 1.0);
+      gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 1);
+      gtk_widget_show (label);
+
+      options->threshold_w = 
+	gtk_adjustment_new (default_threshold, 0.0, 255.0, 1.0, 1.0, 0.0);
+      scale = gtk_hscale_new (GTK_ADJUSTMENT (options->threshold_w));
+      gtk_box_pack_start (GTK_BOX (hbox), scale, TRUE, TRUE, 0);
+      gtk_scale_set_value_pos (GTK_SCALE (scale), GTK_POS_TOP);
+      gtk_range_set_update_policy (GTK_RANGE (scale), GTK_UPDATE_DELAYED);
+      gtk_signal_connect (GTK_OBJECT (options->threshold_w), "value_changed",
+			  GTK_SIGNAL_FUNC (gimp_double_adjustment_update),
+			  &options->threshold);
+      gtk_widget_show (scale);
     }
 
   /*  widgets for fixed size select  */
@@ -362,12 +403,19 @@ selection_options_reset (SelectionOptions *options)
       gtk_adjustment_set_value (GTK_ADJUSTMENT (options->feather_radius_w),
 				options->feather_radius_d);
     }
+
   if (options->antialias_w)
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (options->antialias_w),
 				  options->antialias_d);
+
   if (options->sample_merged_w)
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (options->sample_merged_w),
-				  options->sample_merged_d);
+    {
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (options->sample_merged_w),
+				    options->sample_merged_d);
+      gtk_adjustment_set_value (GTK_ADJUSTMENT (options->threshold_w),
+				default_threshold);
+    }
+
   if (options->fixed_size_w)
     {
       GtkWidget *spinbutton;
@@ -411,7 +459,6 @@ paint_options_init (PaintOptions         *options,
   GtkWidget *vbox;
   GtkWidget *table;
   GtkWidget *scale;
-  GtkWidget *menu;
   GtkWidget *separator;
 
   GimpContext *tool_context = tool_info[tool_type].tool_context;
@@ -440,19 +487,19 @@ paint_options_init (PaintOptions         *options,
 			       _("Dodge or Burn") :
 			       ((tool_type == SMUDGE) ?
 				_("Smudge Tool") :
-				((tool_type == XINPUT_AIRBRUSH) ?
-				 _("Xinput Airbrush") :
-				 "ERROR: Unknown Paint Tool Type")))))))))))),
+/*  				((tool_type == XINPUT_AIRBRUSH) ? */
+/*  				 _("Xinput Airbrush") : */
+				 "ERROR: Unknown Paint Tool Type"))))))))))),
 		     reset_func);
 
   /*  initialize the paint options structure  */
-  options->global        = NULL;
-  options->opacity_w     = NULL;
-  options->paint_mode_w  = NULL;
-  options->incremental_w = NULL;
+  options->global           = NULL;
+  options->opacity_w        = NULL;
+  options->paint_mode_w     = NULL;
+  options->context          = tool_context;
+  options->incremental_w    = NULL;
   options->incremental = options->incremental_d = FALSE;
-
-  options->pressure_options = paint_pressure_options_new (tool_type);
+  options->pressure_options = NULL;
 
   /*  the main vbox  */
   vbox = gtk_vbox_new (FALSE, 2);
@@ -479,6 +526,10 @@ paint_options_init (PaintOptions         *options,
 			     _("Opacity:"), 1.0, 1.0,
 			     scale, 1, FALSE);
 
+  gtk_signal_connect (GTK_OBJECT (tool_context), "opacity_changed",
+		      GTK_SIGNAL_FUNC (tool_options_opacity_changed),
+		      options->opacity_w);
+
   /*  the paint mode menu  */
   switch (tool_type)
     {
@@ -489,22 +540,19 @@ paint_options_init (PaintOptions         *options,
     case AIRBRUSH:
     case CLONE:
     case INK:
-    case XINPUT_AIRBRUSH:
+/*      case XINPUT_AIRBRUSH: */
       gtk_table_set_row_spacing (GTK_TABLE (table), 0, 2);
 
-      options->paint_mode_w = gtk_option_menu_new ();
-      menu =
-	paint_mode_menu_new (tool_options_paint_mode_update, tool_context);
-      gtk_option_menu_set_menu (GTK_OPTION_MENU (options->paint_mode_w), menu);
-      gtk_option_menu_set_history (GTK_OPTION_MENU (options->paint_mode_w),
-				   gimp_context_get_paint_mode (tool_context));
+      options->paint_mode_w =
+	paint_mode_menu_new (tool_options_paint_mode_update, options,
+			     gimp_context_get_paint_mode (tool_context));
       gimp_table_attach_aligned (GTK_TABLE (table), 0, 1,
 				 _("Mode:"), 1.0, 0.5,
 				 options->paint_mode_w, 1, TRUE);
 
-      /* eek */
-      gtk_object_set_data (GTK_OBJECT (options->paint_mode_w), "tool_context",
-			   tool_info[tool_type].tool_context);
+      gtk_signal_connect (GTK_OBJECT (tool_context), "paint_mode_changed",
+			  GTK_SIGNAL_FUNC (tool_options_paint_mode_changed),
+			  options->paint_mode_w);
       break;
     case CONVOLVE:
     case ERASER:
@@ -523,20 +571,20 @@ paint_options_init (PaintOptions         *options,
     {
     case BUCKET_FILL:
     case BLEND:
-    case CLONE:
-    case CONVOLVE:
     case INK:
-    case DODGEBURN:
-    case SMUDGE:
-    case XINPUT_AIRBRUSH:
+      /* case XINPUT_AIRBRUSH: */
       separator = gtk_hseparator_new ();
       gtk_box_pack_start (GTK_BOX (vbox), separator, FALSE, FALSE, 0);
       gtk_widget_show (separator);
       break;
-    case AIRBRUSH:
-    case ERASER:
-    case PAINTBRUSH:
     case PENCIL:
+    case PAINTBRUSH:
+    case ERASER:
+    case AIRBRUSH:
+    case CLONE:
+    case CONVOLVE:
+    case DODGEBURN:
+    case SMUDGE:
       break;
     default:
       break;
@@ -575,6 +623,7 @@ paint_options_init (PaintOptions         *options,
     }
 
   options->pressure_options = paint_pressure_options_new (tool_type);
+
   if (options->pressure_options->frame)
     {
       gtk_box_pack_start (GTK_BOX (options->tool_options.main_vbox),
@@ -610,23 +659,17 @@ paint_options_reset (PaintOptions *options)
 
   if (options->opacity_w)
     {
-      gtk_adjustment_set_value (GTK_ADJUSTMENT (options->opacity_w),
-				gimp_context_get_opacity (default_context) * 100);
+      gimp_context_set_opacity (GIMP_CONTEXT (options->context),
+				gimp_context_get_opacity (default_context));
     }
   if (options->paint_mode_w)
     {
-      GimpContext *context;
-
-      context = (GimpContext *) gtk_object_get_data (GTK_OBJECT (options->paint_mode_w), "tool_context");
-
-      gimp_context_set_paint_mode (GIMP_CONTEXT (context),
-				   gimp_context_get_paint_mode (default_context));
-      gtk_option_menu_set_history (GTK_OPTION_MENU (options->paint_mode_w),
+      gimp_context_set_paint_mode (GIMP_CONTEXT (options->context),
 				   gimp_context_get_paint_mode (default_context));
     }
   if (options->incremental_w)
     {
-      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(options->incremental_w),
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (options->incremental_w),
 				    options->incremental_d);
     }
 
@@ -636,12 +679,12 @@ paint_options_reset (PaintOptions *options)
 static PaintPressureOptions *
 paint_pressure_options_new (ToolType tool_type)
 {
-  PaintPressureOptions *pressure;
+  PaintPressureOptions *pressure = NULL;
   GtkWidget *frame = NULL;
-  GtkWidget *hbox = NULL;
+  GtkWidget *wbox = NULL;
 
   pressure = g_new (PaintPressureOptions, 1);
-    
+
   pressure->opacity  = pressure->opacity_d  = TRUE;
   pressure->pressure = pressure->pressure_d = TRUE;
   pressure->rate     = pressure->rate_d     = FALSE;
@@ -665,9 +708,10 @@ paint_pressure_options_new (ToolType tool_type)
     case PENCIL:
     case SMUDGE:
       frame = gtk_frame_new (_("Pressure Sensitivity"));
-      hbox = gtk_hbox_new (FALSE, 2);
-      gtk_container_add (GTK_CONTAINER (frame), hbox);
-      gtk_widget_show (hbox);
+      wbox = gtk_hwrap_box_new (FALSE);
+      gtk_wrap_box_set_aspect_ratio (GTK_WRAP_BOX (wbox), 6);
+      gtk_container_add (GTK_CONTAINER (frame), wbox);
+      gtk_widget_show (wbox);
       break;
     default:
       break;
@@ -683,7 +727,7 @@ paint_pressure_options_new (ToolType tool_type)
     case PENCIL:
       pressure->opacity_w =
 	gtk_check_button_new_with_label (_("Opacity"));
-      gtk_container_add (GTK_CONTAINER (hbox), pressure->opacity_w);
+      gtk_container_add (GTK_CONTAINER (wbox), pressure->opacity_w);
       gtk_signal_connect (GTK_OBJECT (pressure->opacity_w), "toggled",
 			  GTK_SIGNAL_FUNC (gimp_toggle_button_update),
 			  &pressure->opacity);
@@ -705,8 +749,8 @@ paint_pressure_options_new (ToolType tool_type)
     case ERASER:
     case PAINTBRUSH:
     case SMUDGE:
-      pressure->pressure_w = gtk_check_button_new_with_label (_("Pressure"));
-      gtk_container_add (GTK_CONTAINER (hbox), pressure->pressure_w);
+      pressure->pressure_w = gtk_check_button_new_with_label (_("Hardness"));
+      gtk_container_add (GTK_CONTAINER (wbox), pressure->pressure_w);
       gtk_signal_connect (GTK_OBJECT (pressure->pressure_w), "toggled",
 			  GTK_SIGNAL_FUNC (gimp_toggle_button_update),
 			  &pressure->pressure);
@@ -726,7 +770,7 @@ paint_pressure_options_new (ToolType tool_type)
     case SMUDGE:
       pressure->rate_w =
 	gtk_check_button_new_with_label (_("Rate"));
-      gtk_container_add (GTK_CONTAINER (hbox), pressure->rate_w);
+      gtk_container_add (GTK_CONTAINER (wbox), pressure->rate_w);
       gtk_signal_connect (GTK_OBJECT (pressure->rate_w), "toggled",
 			  GTK_SIGNAL_FUNC (gimp_toggle_button_update),
 			  &pressure->rate);
@@ -750,7 +794,7 @@ paint_pressure_options_new (ToolType tool_type)
     case PENCIL:
       pressure->size_w =
 	gtk_check_button_new_with_label (_("Size"));
-      gtk_container_add (GTK_CONTAINER (hbox), pressure->size_w);
+      gtk_container_add (GTK_CONTAINER (wbox), pressure->size_w);
       gtk_signal_connect (GTK_OBJECT (pressure->size_w), "toggled",
 			  GTK_SIGNAL_FUNC (gimp_toggle_button_update),
 			  &pressure->size);
@@ -770,7 +814,7 @@ paint_pressure_options_new (ToolType tool_type)
     case PENCIL:
       pressure->color_w =
 	gtk_check_button_new_with_label (_("Color"));
-      gtk_container_add (GTK_CONTAINER (hbox), pressure->color_w);
+      gtk_container_add (GTK_CONTAINER (wbox), pressure->color_w);
       gtk_signal_connect (GTK_OBJECT (pressure->color_w), "toggled",
 			  GTK_SIGNAL_FUNC (gimp_toggle_button_update),
 			  &pressure->color);
@@ -861,40 +905,33 @@ paint_options_set_global (gboolean global)
 /*  create a paint mode menu  *************************************************/
 
 GtkWidget *
-paint_mode_menu_new (MenuItemCallback callback,
-		     gpointer         user_data)
+paint_mode_menu_new (GtkSignalFunc    callback,
+		     gpointer         data,
+		     LayerModeEffects initial)
 {
   GtkWidget *menu;
-  gint i;
 
-  static MenuItem option_items[] =
-  {
-    { N_("Normal"), 0, 0, NULL, (gpointer) NORMAL_MODE, NULL, NULL },
-    { N_("Dissolve"), 0, 0, NULL, (gpointer) DISSOLVE_MODE, NULL, NULL },
-    { N_("Behind"), 0, 0, NULL, (gpointer) BEHIND_MODE, NULL, NULL },
-    { N_("Multiply (Burn)"), 0, 0, NULL, (gpointer) MULTIPLY_MODE, NULL, NULL },
-    { N_("Divide (Dodge)"), 0, 0, NULL, (gpointer) DIVIDE_MODE, NULL, NULL },
-    { N_("Screen"), 0, 0, NULL, (gpointer) SCREEN_MODE, NULL, NULL },
-    { N_("Overlay"), 0, 0, NULL, (gpointer) OVERLAY_MODE, NULL, NULL },
-    { N_("Difference"), 0, 0, NULL, (gpointer) DIFFERENCE_MODE, NULL, NULL },
-    { N_("Addition"), 0, 0, NULL, (gpointer) ADDITION_MODE, NULL, NULL },
-    { N_("Subtract"), 0, 0, NULL, (gpointer) SUBTRACT_MODE, NULL, NULL },
-    { N_("Darken Only"), 0, 0, NULL, (gpointer) DARKEN_ONLY_MODE, NULL, NULL },
-    { N_("Lighten Only"), 0, 0, NULL, (gpointer) LIGHTEN_ONLY_MODE, NULL, NULL },
-    { N_("Hue"), 0, 0, NULL, (gpointer) HUE_MODE, NULL, NULL },
-    { N_("Saturation"), 0, 0, NULL, (gpointer) SATURATION_MODE, NULL, NULL },
-    { N_("Color"), 0, 0, NULL, (gpointer) COLOR_MODE, NULL, NULL },
-    { N_("Value"), 0, 0, NULL, (gpointer) VALUE_MODE, NULL, NULL },
-    { NULL, 0, 0, NULL, NULL, NULL, NULL }
-  };
+  menu = gimp_option_menu_new2
+    (FALSE, callback, data, (gpointer) initial,
 
-  for (i = 0; i <= VALUE_MODE; i++)
-    option_items[i].callback = callback;
+     _("Normal"),          (gpointer) NORMAL_MODE, NULL,
+     _("Dissolve"),        (gpointer) DISSOLVE_MODE, NULL,
+     _("Behind"),          (gpointer) BEHIND_MODE, NULL,
+     _("Multiply (Burn)"), (gpointer) MULTIPLY_MODE, NULL,
+     _("Divide (Dodge)"),  (gpointer) DIVIDE_MODE, NULL,
+     _("Screen"),          (gpointer) SCREEN_MODE, NULL,
+     _("Overlay"),         (gpointer) OVERLAY_MODE, NULL,
+     _("Difference"),      (gpointer) DIFFERENCE_MODE, NULL,
+     _("Addition"),        (gpointer) ADDITION_MODE, NULL,
+     _("Subtract"),        (gpointer) SUBTRACT_MODE, NULL,
+     _("Darken Only"),     (gpointer) DARKEN_ONLY_MODE, NULL,
+     _("Lighten Only"),    (gpointer) LIGHTEN_ONLY_MODE, NULL,
+     _("Hue"),             (gpointer) HUE_MODE, NULL,
+     _("Saturation"),      (gpointer) SATURATION_MODE, NULL,
+     _("Color"),           (gpointer) COLOR_MODE, NULL,
+     _("Value"),           (gpointer) VALUE_MODE, NULL,
 
-  menu = build_menu (option_items, NULL);
-
-  for (i = 0; i <= VALUE_MODE; i++)
-    gtk_object_set_user_data (GTK_OBJECT (option_items[i].widget), user_data);
+     NULL);
 
   return menu;
 }
