@@ -171,7 +171,7 @@ query (void)
   {
     { PARAM_INT32, "run_mode", "non-interactive" },
     { PARAM_IMAGE, "image", "Input image (unused)" },
-    { PARAM_DRAWABLE, "drawable", "Input drawable" },
+    { PARAM_DRAWABLE, "drawable", "Input drawable" }
   };
   static gint nargs_ni = sizeof(args_ni) / sizeof (args_ni[0]);
 
@@ -183,7 +183,7 @@ query (void)
     { PARAM_FLOAT, "blur_pct", "Randomization percentage (1 - 100)" },
     { PARAM_FLOAT, "blur_rcount", "Repeat count(1 - 100)" },
     { PARAM_INT32, "seed_type", "Seed type (10 = current time, 11 = seed value)" },
-    { PARAM_INT32, "blur_seed", "Seed value (used only if seed type is 11)" },
+    { PARAM_INT32, "blur_seed", "Seed value (used only if seed type is 11)" }
   };
   static gint nargs = sizeof(args) / sizeof (args[0]);
 
@@ -193,8 +193,6 @@ query (void)
   const gchar *copyrights = "Miles O'Neal, Spencer Kimball, Peter Mattis, Torsten Martinsen, Brian Degenhardt, Federico Mena Quintero, Stephen Norris, Daniel Cotting";
   const gchar *copyright_date = "1995-1998";
 
-  INIT_I18N();
-
   gimp_install_procedure ("plug_in_blur_randomize",
 			  (gchar *) blurb,
 			  (gchar *) help,
@@ -257,8 +255,8 @@ run (gchar   *name,
   /*
    *  Make sure the drawable type is appropriate.
    */
-  if (gimp_drawable_is_rgb(drawable->id) ||
-      gimp_drawable_is_gray(drawable->id))
+  if (gimp_drawable_is_rgb (drawable->id) ||
+      gimp_drawable_is_gray (drawable->id))
     {
       switch (run_mode)
 	{
@@ -266,8 +264,8 @@ run (gchar   *name,
 	   *  If we're running interactively, pop up the dialog box.
 	   */
 	case RUN_INTERACTIVE:
-	  gimp_get_data(PLUG_IN_NAME, &pivals);
-	  if (!blur_dialog())        /* return on Cancel */
+	  gimp_get_data (PLUG_IN_NAME, &pivals);
+	  if (!blur_dialog ())        /* return on Cancel */
 	    return;
 	  break;
 
@@ -604,18 +602,11 @@ blur_dialog (void)
   GtkWidget *table;
   GtkWidget *seed_hbox;
   GtkObject *adj;
-  gchar **argv;
-  gint    argc;
 
-  argc    = 1;
-  argv    = g_new (gchar *, 1);
-  argv[0] = g_strdup ("blur");
-
-  gtk_init (&argc, &argv);
-  gtk_rc_parse (gimp_gtkrc ());
+  gimp_ui_init ("blur", FALSE);
 
   dlg = gimp_dialog_new (BLUR_VERSION, "blur",
-			 gimp_plugin_help_func, "filters/blur.html",
+			 gimp_standard_help_func, "filters/blur.html",
 			 GTK_WIN_POS_MOUSE,
 			 FALSE, TRUE, FALSE,
 
@@ -650,8 +641,8 @@ blur_dialog (void)
   gtk_widget_show (table);
 
   /*  Random Seed  */
-  seed_hbox = gimp_random_seed_new (&pivals.blur_seed, NULL,
-				    &pivals.seed_type, NULL,
+  seed_hbox = gimp_random_seed_new (&pivals.blur_seed,
+				    &pivals.seed_type,
 				    SEED_TIME, SEED_USER);
   gimp_table_attach_aligned (GTK_TABLE (table), 0, 0,
                              _("Random Seed:"), 1.0, 0.5,
